@@ -5,7 +5,7 @@
   To compare tree /media/dvd and /original/dir :
       find /media/dvd -exec compare_file '{}' /media/dvd /original/dir ';'
 
-  Copyright 2008 - 2010 Thomas Schmitt, <scdbackup@gmx.net>
+  Copyright 2008 - 2015 Thomas Schmitt, <scdbackup@gmx.net>
 
   Provided under GPL version 2 or later.
 
@@ -28,6 +28,10 @@
 #include <string.h>
 #include <time.h>
 
+/* O_BINARY is needed for Cygwin but undefined elsewhere */
+#ifndef O_BINARY
+#define O_BINARY 0
+#endif
 
 /* @param flag bit0= single letters */
 char *Ftypetxt(mode_t st_mode, int flag)
@@ -107,10 +111,12 @@ int Compare_2_files(char *adr1, char *adr2, char *adrc, int flag)
  }
  strcpy(a, Ftypetxt(s1.st_mode, 1));
  strcat(a, " ");
- if(adrc[0])
-   strcat(a, adrc);
- else
+ if(adrc[0]) {
+   if(strlen(a) + strlen(adrc) < 4096)
+     strcat(a, adrc);
+ } else {
    strcat(a, ".");
+ }
 
  ret= lstat(adr2, &s2);
  if(ret==-1) {
@@ -180,12 +186,12 @@ int Compare_2_files(char *adr1, char *adr2, char *adrc, int flag)
    }
  }
  if(S_ISREG(s1.st_mode) && S_ISREG(s2.st_mode)) {
-   fd1= open(adr1, O_RDONLY);
+   fd1= open(adr1, O_RDONLY | O_BINARY);
    if(fd1==-1) {
      printf("- %s : cannot open() : %s\n", adr1, strerror(errno));
      return(0);
    }
-   fd2= open(adr2, O_RDONLY);
+   fd2= open(adr2, O_RDONLY | O_BINARY);
    if(fd2==-1) {
      printf("- %s : cannot open() : %s\n", adr2, strerror(errno));
      close(fd1);
@@ -278,6 +284,18 @@ int main(int argc, char **argv)
           argv[0], argv[1], argv[2]);
    exit(2);
  }
+ if(strlen(argv[1]) >= 4096) {
+   fprintf(stderr, "path exceeds size limit of 4095\n");
+   exit(3);
+ }
+ if(strlen(argv[1]) - strlen(argv[2]) > 4000) {
+   fprintf(stderr, "common address part exceeds size limit of 4000\n");
+   exit(3);
+ }
+ if(strlen(argv[3]) + 1 + strlen(argv[1]) - strlen(argv[2]) >= 4096) {
+   fprintf(stderr, "prefix2 exceeds size limit of 4095\n");
+   exit(3);
+ }
  strcpy(adr1, argv[1]);
  strcpy(adrc, argv[1]+strlen(argv[2]));
  sprintf(adr2, "%s%s%s",
