@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2016 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2017 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -1346,7 +1346,7 @@ next_command:;
  } else if(strcmp(cmd,"for_backup")==0) {
    Xorriso_option_hardlinks(xorriso, "on", 0);
    Xorriso_option_acl(xorriso, "on", 0);
-   Xorriso_option_xattr(xorriso, "on", 0);
+   Xorriso_option_xattr(xorriso, "any", 0);
    Xorriso_option_md5(xorriso, "on", 0);
    ret= 1;
 
