@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2016 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -167,9 +167,19 @@ int Xorriso__get_di(IsoNode *node, dev_t *dev, ino_t *ino, int flag)
    goto ex;
  }
  vpt= (unsigned char *) value;
+ if(vpt[0] > sizeof(ino_t)) {
+
+   /* >>> obviously not the same system that recorded the device number */; 
+
+ }
  for(i= 1; i <= vpt[0] && i < (int) value_length; i++)
    *dev= ((*dev) << 8) | vpt[i];
  i_end= i + vpt[i] + 1;
+ if(vpt[i] > sizeof(ino_t)) {
+
+   /* >>> obviously not the same system that recorded the inode number */; 
+
+ }
  for(i++; i < i_end && i < (int) value_length; i++)
    *ino= ((*ino) << 8) | vpt[i];
  free(value);
@@ -468,7 +478,7 @@ int Xorriso_make_hln_array(struct XorrisO *xorriso, int flag)
  int ret;
 
  if(xorriso->hln_array != NULL && !(flag & 1)) {
-   /* If no fresh image manipulations occured: keep old array */
+   /* If no fresh image manipulations occurred: keep old array */
    if(!xorriso->hln_change_pending)
      return(2);
    ret= Xorriso_remake_hln_array(xorriso, 0);
@@ -646,9 +656,9 @@ int Xorriso_hardlink_update(struct XorrisO *xorriso, int *compare_result,
    "xorriso_DEBUG: old_idx= %d , low= %d , high= %d , iso= '%s' , disk='%s'\n",
    old_idx, low, high, iso_rr_path, disk_path);
    fprintf(stderr,
-         "xorriso_DEBUG: old_dev= %lu , old_ino= %lu ,  dev= %lu , ino= %lu\n",
-         (unsigned long) old_dev, (unsigned long) old_ino,
-         (unsigned long) stbuf.st_dev, (unsigned long) stbuf.st_ino);
+         "xorriso_DEBUG: old_dev= %lu , old_ino= %.f ,  dev= %lu , ino= %.f\n",
+         (unsigned long) old_dev, (double) old_ino,
+         (unsigned long) stbuf.st_dev, (double) stbuf.st_ino);
 
    if(idx >= 0 && idx != old_idx)
      fprintf(stderr, "xorriso_DEBUG: idx= %d , old_idx = %d\n", idx, old_idx);
@@ -667,8 +677,8 @@ int Xorriso_hardlink_update(struct XorrisO *xorriso, int *compare_result,
  dev_t dev;
 
  Xorriso__get_di(xorriso->di_array[i], &dev, &ino, 0);
- fprintf(stderr, "xorriso_DEBUG: iso_sibling= '%s' , dev= %lu , ino= %lu\n",
-         node_path, (unsigned long) dev, (unsigned long) ino);
+ fprintf(stderr, "xorriso_DEBUG: iso_sibling= '%s' , dev= %lu , ino= %.f\n",
+         node_path, (unsigned long) dev, (double) ino);
 }
 #endif /* Xorriso_hardlink_update_debuG */
 
