@@ -4,7 +4,7 @@
    a command line oriented batch and dialog tool which creates, loads,
    manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2015 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2018 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -18,8 +18,8 @@
 /* The minimum version of libisoburn to be used with this version of xorriso
 */
 #define xorriso_libisoburn_req_major  1
-#define xorriso_libisoburn_req_minor  4
-#define xorriso_libisoburn_req_micro  2
+#define xorriso_libisoburn_req_minor  5
+#define xorriso_libisoburn_req_micro  0
 
 
 struct SpotlisT;          /* List of intervals with different read qualities */
@@ -217,7 +217,7 @@ int Xorriso_set_abort_severity(struct XorrisO *xorriso, int flag);
 int Xorriso_report_lib_versions(struct XorrisO *xorriso, int flag);
 
 /* @return 0= stbuf content is valid ,
-          -1 = path not found , -2 = severe error occured
+          -1 = path not found , -2 = severe error occurred
 */
 int Xorriso_iso_lstat(struct XorrisO *xorriso, char *path, struct stat *stbuf,
                       int flag);
@@ -622,6 +622,10 @@ int Xorriso_hfsplus_bless(struct XorrisO *xorriso, char *path,
 
 int Xorriso_pretend_full_disc(struct XorrisO *xorriso, int flag);
 
+int Xorriso_scsi_dev_family(struct XorrisO *xorriso, int flag);
+
+int Xorriso_use_immed_bit(struct XorrisO *xorriso, int flag);
+
 
 int Xorriso_apply_sort_file(struct XorrisO *xorriso, char *path, int flag);
 
@@ -635,5 +639,15 @@ int Xorriso_set_file_name_limit(struct XorrisO *xorriso, int value, int flag);
 int Xorriso_truncate_path_comps(struct XorrisO *xorriso, char *path,
                                 char *buffer, char **resultpt, int flag);
 
+int Xorriso_graftable_pathspec(struct XorrisO *xorriso, char *in_pathspec,
+                               char *pathspec, int flag);
+
+int Xorriso_parse_gpt_guid(struct XorrisO *xorriso, char *text, int flag);
+
+int Xorriso_format_guid(struct XorrisO *xorriso, uint8_t guid[16], char *line,
+                        int flag);
+
+int Xorriso_make_guid(struct XorrisO *xorriso, char *line, int flag);
+
 #endif /* Xorrisoburn_includeD */
 
